==> multiplex_2.0.tar.gz: multiplex/man/rel.sys.Rd <==
\name{rel.sys}
\alias{rel.sys}
\title{
Relational System
}
\description{
Create the Relation System of a multiple network.
}
\usage{
rel.sys(x, type = c("tolist", "toarray"), bonds = c("entire", "strong", "weak", 
        "asym", "recp", "txch", "tent", "mixd", "full"), sel = NULL, 
        loops = FALSE, att = NULL, prsep)
}
\arguments{
  \item{x}{
   an array; usually with three dimensions of stacked matrices where the multiple relations are placed.
}
  \item{type}{
   if the transformation is from (array of) matrices into lists of pairwise relations or vice versa
 }
  \item{bonds}{
   the type of bonds to be used in the creation of the relational system (default the `entire' network)
}
  \item{sel}{
   (optional) the set of actors to be selected. For \code{"toarray"} \code{att} and \code{noatt} also supported (see details)
}
  \item{loops}{
   (logical) whether or not the loops should be considered in the relational system
}
  \item{att}{
   the arrays in \code{x} corresponding to attributes
}
  \item{prsep}{
   (optional) the pair separator for the pairwise relations
  }
}
\details{
This function serves to establish a particular \emph{system} in the network typically by the `\code{bonds}' argument, but also through `\code{sel}'. In case that ``\code{entire}'' is chosen with the former option, then all nodes with ties are considered in the relational system without isolated nodes. ``\code{strong}'' bonds are relational bundles with a mutual character, whereas \code{weak} bonds are those pattern exclusively without mutual character. A single bundle pattern or combination of these is also possible.

The latter argument allows selecting network members as well, and this can be done with a scalar or a vector given the location of the actor(s) in the input data or else by their label names. Moreover, it is possible to select the actors having or \emph{not} a particular attribute, which can be specified by an array as well; use ``\code{att}'' or ``\code{noatt}'' for the two possibilities in the `\code{sel}' argument, and this is specified in \code{Attrs} of the output.
}
\value{
An object of `\code{Rel.System}' class for the \code{type = "tolist"} (default option).
The items are:
   \item{ord}{order of the network relational system}
   \item{nodes}{the nodes in the relational system}
   \item{sel}{the selected set of actors}
   \item{sys.ord}{the order of the relational system with the chosen bond type}
   \item{incl}{the nodes included the relational system with the chosen bond type}
   \item{excl}{the nodes excluded the relational system with the chosen bond type}
   \item{bond.type}{the type of bonds used in the relational system creation}
   \item{size}{number of ties in the relational system}
   \item{Note}{(optional) note}
   \item{prsep}{the pairwise separator of the relational system}
   \item{Ties}{the ties in the relational system}
   \item{Attrs.ord}{if \code{att} is not \code{NULL}, the number of nodes with the chosen attribute(s) }
   \item{Attrs}{if \code{att} is not \code{NULL}, the actors with the chosen attribute(s)}

For \code{type = "toarray"} the output is a dichotomous 2D or 3D array recording the relations among the actors in the network.
%% ...
}
%\references{
%
%}
\author{
Antonio Rivero Ostoic
}
%\note{
%
%}

%% ~Make other sections like Warning with \section{Warning }{....} ~

\seealso{
\code{\link{expos}}, \code{\link{bundles}}, \code{\link{neighb}}
}
\examples{
## Create the data: two binary relations among three elements
arr <- round( replace( array( runif(18), c(3 ,3, 2) ), array( runif(18),
       c(3, 3, 2) ) > .9, 3 ) )

## Determine the system of strong bonds
rel.sys(arr, bonds = "strong")

## the first array is for attributes
rel.sys(arr, att = 1)

## select the first node
rel.sys(arr, sel = 1)

}

\keyword{ models }
\keyword{ attribute }

==> multiplex_2.3.tar.gz: multiplex/man/rel.sys.Rd <==
\name{rel.sys}
\alias{rel.sys}
\title{
Relational System
}
\description{
Create the Relation System of a multiple network.
}
\usage{
rel.sys(x, type = c("tolist", "toarray"), bonds = c("entire", "strong", "weak", 
        "asym", "recp", "txch", "tent", "mixd", "full"), sel = NULL, 
        loops = FALSE, att = NULL, prsep)
}
\arguments{
  \item{x}{
   an array; usually with three dimensions of stacked matrices where the multiple relations are placed.
}
  \item{type}{
   if the transformation is from (array of) matrices into lists of pairwise relations or vice versa
 }
  \item{bonds}{
   the type of bonds to be used in the creation of the relational system (default the `entire' network)
}
  \item{sel}{
   (optional) the set of actors to be selected. For \code{"toarray"} \code{att} and \code{noatt} also supported (see details)
}
  \item{loops}{
   (logical) whether or not the loops should be considered in the relational system
}
  \item{att}{
   the arrays in \code{x} corresponding to attributes
}
  \item{prsep}{
   (optional) the pair separator for the pairwise relations
  }
}
\details{
When the type of bonds chosen is \code{entire} then the nodes with ties are considered in the relational system without isolated nodes. \code{strong} bonds are relational bundles with a mutual character, whereas \code{weak} bonds are those pattern exclusively without mutual character.

When selecting from a list with actor attributes, it is also possible to select the network members having or \emph{not} the attribute that is specified in the \code{Attrs} output. Use \code{att} or \code{noatt} for the two options.
}
\value{
An object of `\code{Rel.System}' class for the \code{type = "tolist"} (default) option.
The items are:
   \item{ord}{order of the network relational system}
   \item{nodes}{the nodes in the relational system}
   \item{sel}{the selected set of actors}
   \item{sys.ord}{the order of the relational system with the chosen bond type}
   \item{incl}{the nodes included the relational system with the chosen bond type}
   \item{excl}{the nodes excluded the relational system with the chosen bond type}
   \item{bond.type}{the type of bonds used in the relational system creation}
   \item{size}{number of ties in the relational system}
   \item{Note}{(optional) note}
   \item{prsep}{the pairwise separator of the relational system}
   \item{Ties}{the ties in the relational system}
   \item{Attrs.ord}{if \code{att} is not \code{NULL}, the number of nodes with the chosen attribute(s) }
   \item{Attrs}{if \code{att} is not \code{NULL}, the actors with the chosen attribute(s)}

For \code{type = "toarray"} the output is a dichotomous 2D or 3D array recording the relations among the actors in the network.
%% ...
}
%\references{
%
%}
\author{
Antonio Rivero Ostoic
}
%\note{
%
%}

%% ~Make other sections like Warning with \section{Warning }{....} ~

\seealso{
\code{\link{expos}}, \code{\link{bundles}}, \code{\link{neighb}}
}
\examples{
## Create the data: two binary relations among three elements
arr <- round( replace( array( runif(18), c(3 ,3, 2) ), array( runif(18),
       c(3, 3, 2) ) > .9, 3 ) )

## Determine the system of strong bonds
rel.sys(arr, bonds = "strong")

## the first array is for attributes
rel.sys(arr, att = 1)

## select the first node
rel.sys(arr, sel = 1)

}

\keyword{ models }
\keyword{ attribute }
